==> mysql-8.0_8.0.42.orig.tar.gz: mysql-8.0.42/router/src/routing/src/classic_auth_forwarder.h <==
/*
  Copyright (c) 2022, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ROUTING_CLASSIC_AUTH_FORWARDER_INCLUDED
#define ROUTING_CLASSIC_AUTH_FORWARDER_INCLUDED

#include "forwarding_processor.h"

/**
 * forward authentication between a client and server.
 *
 * started from the server after AuthSwitch
 */
class AuthForwarder : public ForwardingProcessor {
 public:
  AuthForwarder(MysqlRoutingClassicConnectionBase *conn,
                bool client_requested_full_auth = false)
      : ForwardingProcessor(conn),
        client_requested_full_auth_{client_requested_full_auth} {}

  enum class Stage {
    Init,

    AuthMethodSwitch,

    Response,

    Error,
    Ok,

    Done,
  };

  stdx::expected<Result, std::error_code> process() override;

  void stage(Stage stage) { stage_ = stage; }
  [[nodiscard]] Stage stage() const { return stage_; }

 private:
  stdx::expected<Result, std::error_code> init();
  stdx::expected<Result, std::error_code> auth_method_switch();
  stdx::expected<Result, std::error_code> response();
  stdx::expected<Result, std::error_code> error();
  stdx::expected<Result, std::error_code> ok();

  Stage stage_{Stage::Init};
  bool client_requested_full_auth_;
};

#endif

==> mysql-8.0.32.tar.gz: mysql-8.0.32/router/src/routing/src/classic_auth_forwarder.h <==
/*
  Copyright (c) 2022, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef ROUTING_CLASSIC_AUTH_FORWARDER_INCLUDED
#define ROUTING_CLASSIC_AUTH_FORWARDER_INCLUDED

#include <memory>  // unique_ptr
#include <string_view>
#include <system_error>

#include <openssl/ssl.h>

#include "classic_connection.h"
#include "mysql/harness/stdx/expected.h"

/**
 * forward authentication between a client and server.
 *
 * started from the server after AuthSwitch
 */
class AuthForwarder : public Processor {
 public:
  using Processor::Processor;

  enum class Stage {
    Init,

    AuthMethodSwitch,

    Response,

    Error,
    Ok,

    Done,
  };

  stdx::expected<Result, std::error_code> process() override;

  void stage(Stage stage) { stage_ = stage; }
  [[nodiscard]] Stage stage() const { return stage_; }

 private:
  stdx::expected<Result, std::error_code> init();
  stdx::expected<Result, std::error_code> auth_method_switch();
  stdx::expected<Result, std::error_code> response();
  stdx::expected<Result, std::error_code> error();
  stdx::expected<Result, std::error_code> ok();

  Stage stage_{Stage::Init};
};

#endif
